@@ -1073,7 +1073,7 @@ static int do_read(int all, char *force_ver, char *base_dir, char *conf_file, in
 			arg2 = next_word(arg);
 			meta_expand(arg2, &g, NULL, version, ME_ALL);
 			snprintf(env, sizeof(env), "%s=%s", arg, (g.pathc ? g.pathv[0] : ""));
-			putenv(env);
+			putenv(xstrdup(env));
 			one_err = 0;
 		}
 
